/*******************************************************************************
* File Name: SDCARD_PM.c
* Version 2.50
*
* Description:
*  This file contains the setup, control and status commands to support
*  component operations in low power mode.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "SDCARD_PVT.h"

static SDCARD_BACKUP_STRUCT SDCARD_backup =
{
    SDCARD_DISABLED,
    SDCARD_BITCTR_INIT,
};


/*******************************************************************************
* Function Name: SDCARD_SaveConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void SDCARD_SaveConfig(void) 
{

}


/*******************************************************************************
* Function Name: SDCARD_RestoreConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void SDCARD_RestoreConfig(void) 
{

}


/*******************************************************************************
* Function Name: SDCARD_Sleep
********************************************************************************
*
* Summary:
*  Prepare SPIM Component goes to sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  SDCARD_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void SDCARD_Sleep(void) 
{
    /* Save components enable state */
    SDCARD_backup.enableState = ((uint8) SDCARD_IS_ENABLED);

    SDCARD_Stop();
}


/*******************************************************************************
* Function Name: SDCARD_Wakeup
********************************************************************************
*
* Summary:
*  Prepare SPIM Component to wake up.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  SDCARD_backup - used when non-retention registers are restored.
*  SDCARD_txBufferWrite - modified every function call - resets to
*  zero.
*  SDCARD_txBufferRead - modified every function call - resets to
*  zero.
*  SDCARD_rxBufferWrite - modified every function call - resets to
*  zero.
*  SDCARD_rxBufferRead - modified every function call - resets to
*  zero.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void SDCARD_Wakeup(void) 
{
    #if(SDCARD_RX_SOFTWARE_BUF_ENABLED)
        SDCARD_rxBufferFull  = 0u;
        SDCARD_rxBufferRead  = 0u;
        SDCARD_rxBufferWrite = 0u;
    #endif /* (SDCARD_RX_SOFTWARE_BUF_ENABLED) */

    #if(SDCARD_TX_SOFTWARE_BUF_ENABLED)
        SDCARD_txBufferFull  = 0u;
        SDCARD_txBufferRead  = 0u;
        SDCARD_txBufferWrite = 0u;
    #endif /* (SDCARD_TX_SOFTWARE_BUF_ENABLED) */

    /* Clear any data from the RX and TX FIFO */
    SDCARD_ClearFIFO();

    /* Restore components block enable state */
    if(0u != SDCARD_backup.enableState)
    {
        SDCARD_Enable();
    }
}


/* [] END OF FILE */
